Stan Math Library: Class Hierarchy

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Class Hierarchy
This inheritance list is sorted roughly, but not completely, alphabetically:
[detail level 123]

C stan::math::accumulator< T > | Class to accumulate values and eventually return their sum
C stan::math::apply_scalar_unary< F, T > | Base template class for vectorization of unary scalar functions defined by a template class `F` to a scalar, standard library vector, or Eigen dense matrix expression template
C stan::math::apply_scalar_unary< F, double > | Template specialization for vectorized functions applying to double arguments
C stan::math::apply_scalar_unary< F, int > | Template specialization for vectorized functions applying to integer arguments
C stan::math::apply_scalar_unary< F, stan::math::fvar< T > > | Template specialization to fvar for vectorizing a unary scalar function
C stan::math::apply_scalar_unary< F, stan::math::var > | Template specialization to var for vectorizing a unary scalar function
C stan::math::apply_scalar_unary< F, std::vector< T > > | Template specialization for vectorized functions applying to standard vector containers
C stan::math::array_builder< T > | Structure for building up arrays in an expression (rather than in statements) using an argumentchaining add() method and a getter method array() to return the result
C stan::math::AutodiffStackStorage< ChainableT, ChainableAllocT > |
C stan::math::detail::bounded< T_y, T_low, T_high, y_is_vec > |
C stan::math::detail::bounded< T_y, T_low, T_high, true > |
►C stan::math::chainable_alloc | A chainable_alloc is an object which is constructed and destructed normally but the memory lifespan is managed along with the arena allocator for the gradient calculation
C stan::math::LDLT_alloc< R, C > | This object stores the actual (double typed) LDLT factorization of an Eigen::Matrix<var> along with pointers to its vari's which allow the *_ldlt functions to save memory
C stan::math::child_type< T > | Primary template class for metaprogram to compute child type of T
C stan::math::child_type< T_struct< T_child > > | Specialization for template classes / structs
C stan::math::common_type< T1, T2 > |
C stan::math::common_type< Eigen::Matrix< T1, R, C >, Eigen::Matrix< T2, R, C > > |
C stan::math::common_type< std::vector< T1 >, std::vector< T2 > > |
C stan::math::container_view< T1, T2 > | Primary template class for container view of array y with same structure as T1 and size as x
C stan::math::container_view< dummy, T2 > | Dummy type specialization, used in conjunction with struct dummy as described above
C stan::math::container_view< Eigen::Matrix< T1, R, C >, Eigen::Matrix< T2, R, C > > | Template specialization for Eigen::Map view of array with scalar type T2 with size inferred from input Eigen::Matrix
C stan::math::container_view< Eigen::Matrix< T1, R, C >, T2 > | Template specialization for scalar view of array y with scalar type T2
C stan::math::container_view< std::vector< Eigen::Matrix< T1, R, C > >, Eigen::Matrix< T2, R, C > > | Template specialization for matrix view of array y with scalar type T2 with shape equal to x
C stan::math::container_view< std::vector< T1 >, T2 > | Template specialization for scalar view of array y with scalar type T2 with proper indexing inferred from input vector x of scalar type T1
C stan::contains_fvar< T1, T2, T3, T4, T5, T6 > | Metaprogram to calculate the base scalar return type resulting from promoting all the scalar types of the template parameters
C stan::contains_nonconstant_struct< T1, T2, T3, T4, T5, T6 > |
C stan::contains_vector< T1, T2, T3, T4, T5, T6 > |
C stan::math::coupled_ode_observer | Observer for the coupled states
C stan::math::coupled_ode_system< F, T1, T2 > | Base template class for a coupled ordinary differential equation system, which adds sensitivities to the base system
C stan::math::coupled_ode_system< F, double, double > | The coupled ode system for known initial values and known parameters
C stan::math::coupled_ode_system< F, double, stan::math::var > | The coupled ODE system for known initial values and unknown parameters
C stan::math::coupled_ode_system< F, stan::math::var, double > | The coupled ODE system for unknown initial values and known parameters
C stan::math::coupled_ode_system< F, stan::math::var, stan::math::var > | The coupled ode system for unknown intial values and unknown parameters
C stan::math::cvodes_ode_data< F, T_initial, T_param > | CVODES ode data holder object which is used during CVODES integration for CVODES callbacks
C stan::math::dummy | Empty struct for use in boost::condtional<is_constant_struct<T1>::value, T1, dummy>::type as false condtion for safe indexing
C stan::error_index |
C stan::math::fvar< T > |
C Eigen::internal::general_matrix_matrix_product< Index, stan::math::var, LhsStorageOrder, ConjugateLhs, stan::math::var, RhsStorageOrder, ConjugateRhs, ColMajor > |
C Eigen::internal::general_matrix_vector_product< Index, stan::math::var, RowMajor, ConjugateLhs, stan::math::var, ConjugateRhs > |
C Eigen::internal::general_matrix_vector_product< Index, stan::math::var, ColMajor, ConjugateLhs, stan::math::var, ConjugateRhs > | Override matrix-vector and matrix-matrix products to use more efficient implementation
C stan::math::include_summand< propto, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10 > | Template metaprogram to calculate whether a summand needs to be included in a proportional (log) probability calculation
C stan::math::index_type< T > | Primary template class for the metaprogram to compute the index type of a container
C stan::math::index_type< const T > | Template class for metaprogram to compute the type of indexes used in a constant container type
C stan::math::index_type< Eigen::Matrix< T, R, C > > | Template metaprogram defining typedef for the type of index for an Eigen matrix, vector, or row vector
C stan::math::index_type< std::vector< T > > | Template metaprogram class to compute the type of index for a standard vector
C stan::is_constant< T > | Metaprogramming struct to detect whether a given type is constant in the mathematical sense (not the C++ `const` sense)
C stan::is_constant_struct< T > | Metaprogram to determine if a type has a base scalar type that can be assigned to type double
C stan::is_constant_struct< Eigen::Block< T > > |
C stan::is_constant_struct< Eigen::Matrix< T, R, C > > |
C stan::is_constant_struct< std::vector< T > > |
C stan::is_fvar< T > |
C stan::is_fvar< stan::math::fvar< T > > |
C stan::is_var< T > |
C stan::is_var< stan::math::var > |
C stan::is_var_or_arithmetic< T1, T2, T3, T4, T5, T6 > |
C stan::is_vector< T > |
C stan::is_vector< const T > |
C stan::is_vector< Eigen::Block< T > > |
C stan::is_vector< Eigen::Matrix< T, 1, Eigen::Dynamic > > |
C stan::is_vector< Eigen::Matrix< T, Eigen::Dynamic, 1 > > |
C stan::is_vector< std::vector< T > > |
C stan::is_vector_like< T > | Template metaprogram indicates whether a type is vector_like
C stan::is_vector_like< const T > | Template metaprogram indicates whether a type is vector_like
C stan::is_vector_like< Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > > | Template metaprogram indicates whether a type is vector_like
C stan::is_vector_like< T * > | Template metaprogram indicates whether a type is vector_like
C stan::math::LDLT_factor< T, R, C > |
C stan::math::LDLT_factor< stan::math::var, R, C > | A template specialization of src/stan/math/matrix/LDLT_factor.hpp for stan::math::var which can be used with all the *_ldlt functions
C stan::math::LDLT_factor< T, R, C > | LDLT_factor is a thin wrapper on Eigen::LDLT to allow for reusing factorizations and efficient autodiff of things like log determinants and solutions to linear systems
C std::numeric_limits< stan::math::fvar< T > > |
C std::numeric_limits< stan::math::var > | Specialization of numeric limits for var objects
C Eigen::NumTraits< stan::math::fvar< T > > | Numerical traits template override for Eigen for automatic gradient variables
C Eigen::NumTraits< stan::math::var > | Numerical traits template override for Eigen for automatic gradient variables
C stan::math::ode_system< F > | Internal representation of an ODE model object which provides convenient Jacobian functions to obtain gradients wrt to states and parameters
C stan::math::OperandsAndPartials< T1, T2, T3, T4, T5, T6, T_return_type > | This class builds partial derivatives with respect to a set of operands
C stan::math::OperandsAndPartials< T1, T2, T3, T4, T5, T6, typename stan::math::fvar< T_partials_return > > | This class builds partial derivatives with respect to a set of operands
C stan::math::OperandsAndPartials< T1, T2, T3, T4, T5, T6, stan::math::var > | This class builds partial derivatives with respect to a set of operands
C stan::partials_return_type< T1, T2, T3, T4, T5, T6 > |
C stan::partials_type< T > |
C stan::partials_type< stan::math::fvar< T > > |
C stan::partials_type< stan::math::var > |
C stan::math::pass_type< T > |
C stan::math::pass_type< double > |
C stan::math::pass_type< int > |
C stan::math::promote_scalar_struct< T, S > | General struct to hold static function for promoting underlying scalar types
C stan::math::promote_scalar_struct< T, Eigen::Matrix< S, 1,-1 > > | Struct to hold static function for promoting underlying scalar types
C stan::math::promote_scalar_struct< T, Eigen::Matrix< S,-1, 1 > > | Struct to hold static function for promoting underlying scalar types
C stan::math::promote_scalar_struct< T, Eigen::Matrix< S,-1,-1 > > | Struct to hold static function for promoting underlying scalar types
C stan::math::promote_scalar_struct< T, std::vector< S > > | Struct to hold static function for promoting underlying scalar types
C stan::math::promote_scalar_struct< T, T > | Struct to hold static function for promoting underlying scalar types
C stan::math::promote_scalar_type< T, S > | Template metaprogram to calculate a type for converting a convertible type
C stan::math::promote_scalar_type< T, Eigen::Matrix< S, 1, Eigen::Dynamic > > | Template metaprogram to calculate a type for a row vector whose underlying scalar is converted from the second template parameter type to the first
C stan::math::promote_scalar_type< T, Eigen::Matrix< S, Eigen::Dynamic, Eigen::Dynamic > > | Template metaprogram to calculate a type for a matrix whose underlying scalar is converted from the second template parameter type to the first
C stan::math::promote_scalar_type< T, Eigen::Matrix< S, Eigen::Dynamic, 1 > > | Template metaprogram to calculate a type for a vector whose underlying scalar is converted from the second template parameter type to the first
C stan::math::promote_scalar_type< T, std::vector< S > > | Template metaprogram to calculate a type for a container whose underlying scalar is converted from the second template parameter type to the first
C stan::math::promoter< F, T > |
C stan::math::promoter< Eigen::Matrix< F, R, C >, Eigen::Matrix< T, R, C > > |
C stan::math::promoter< Eigen::Matrix< T, R, C >, Eigen::Matrix< T, R, C > > |
C stan::math::promoter< std::vector< F >, std::vector< T > > |
C stan::math::promoter< std::vector< T >, std::vector< T > > |
C stan::math::promoter< T, T > |
C stan::return_type< T1, T2, T3, T4, T5, T6 > | Metaprogram to calculate the base scalar return type resulting from promoting all the scalar types of the template parameters
C Eigen::internal::scalar_product_traits< double, stan::math::var > | Scalar product traits override for Eigen for automatic gradient variables
C Eigen::internal::scalar_product_traits< stan::math::var, double > | Scalar product traits override for Eigen for automatic gradient variables
C stan::scalar_type< T > | Metaprogram structure to determine the base scalar type of a template argument
C stan::scalar_type< Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > > |
C stan::scalar_type< T * > |
C stan::scalar_type_pre< T > | Metaprogram structure to determine the type of first container of the base scalar type of a template argument
C stan::math::seq_view< T, S > |
C stan::math::seq_view< double, std::vector< int > > |
C stan::math::seq_view< T, Eigen::Matrix< S, 1, Eigen::Dynamic > > |
C stan::math::seq_view< T, Eigen::Matrix< S, Eigen::Dynamic, 1 > > |
C stan::math::seq_view< T, Eigen::Matrix< S, Eigen::Dynamic, Eigen::Dynamic > > |
C stan::math::seq_view< T, std::vector< S > > |
C stan::math::seq_view< T, std::vector< std::vector< T > > > |
C stan::math::seq_view< T, std::vector< T > > |
C Eigen::internal::significant_decimals_default_impl< stan::math::fvar< T >, false > | Implemented this for printing to stream
C Eigen::internal::significant_decimals_default_impl< stan::math::var, false > | Implemented this for printing to stream
C stan::size_of_helper< T, is_vec > |
C stan::size_of_helper< T, true > |
C stan::math::stack_alloc | An instance of this class provides a memory pool through which blocks of raw memory may be allocated and then collected simultaneously
C stan::math::store_type< T > |
C stan::math::store_type< double > |
C stan::math::store_type< Eigen::Matrix< S, 1, Eigen::Dynamic > > |
C stan::math::store_type< Eigen::Matrix< S, Eigen::Dynamic, 1 > > |
C stan::math::store_type< Eigen::Matrix< S, Eigen::Dynamic, Eigen::Dynamic > > |
C stan::math::store_type< int > |
C stan::math::store_type< S > |
C stan::math::store_type< std::vector< int > > |
C stan::math::store_type< std::vector< S > > |
C stan::math::store_type< std::vector< std::vector< T > > > |
C stan::math::store_type< std::vector< T > > |
C stan::math::value_type< T > | Primary template class for metaprogram to compute the type of values stored in a container
C stan::math::value_type< const T > | Template class for metaprogram to compute the type of values stored in a constant container
C stan::math::value_type< Eigen::Matrix< T, R, C > > | Template metaprogram defining the type of values stored in an Eigen matrix, vector, or row vector
C stan::math::value_type< std::vector< T > > | Template metaprogram class to compute the type of values stored in a standard vector
C stan::math::var | Independent (input) and dependent (output) variables for gradients
►C stan::math::vari | The variable implementation base class
C stan::math::cholesky_decompose_v_vari |
C stan::math::gevv_vvv_vari |
C stan::math::op_ddv_vari |
C stan::math::op_dv_vari |
C stan::math::op_dvd_vari |
C stan::math::op_dvv_vari |
C stan::math::op_matrix_vari |
►C stan::math::op_v_vari |
C stan::math::precomp_v_vari |
C stan::math::op_vd_vari |
C stan::math::op_vdd_vari |
C stan::math::op_vdv_vari |
C stan::math::op_vector_vari |
►C stan::math::op_vv_vari |
C stan::math::precomp_vv_vari |
C stan::math::op_vvd_vari |
►C stan::math::op_vvv_vari |
C stan::math::precomp_vvv_vari |
C stan::math::precomputed_gradients_vari | A variable implementation taking a sequence of operands and partial derivatives with respect to the operands
C stan::math::stored_gradient_vari | A var implementation that stores the daughter variable implementation pointers and the partial derivative with respect to the result explicitly in arrays constructed on the auto-diff memory stack
►C stan::math::sum_v_vari | Class for sums of variables constructed with standard vectors
C stan::math::sum_eigen_v_vari | Class for representing sums with constructors for Eigen
C stan::VectorBuilder< used, T1, T2, T3, T4, T5, T6, T7 > | VectorBuilder allocates type T1 values to be used as intermediate values
C stan::VectorBuilderHelper< T1, used, is_vec > | VectorBuilder allocates type T1 values to be used as intermediate values
C stan::VectorBuilderHelper< T1, true, false > |
C stan::VectorBuilderHelper< T1, true, true > | Template specialization for using a vector
C stan::VectorBuilderHelper< T1, used, stan::contains_vector< T2, T3, T4, T5, T6, T7 >::value > |
C stan::VectorView< T, is_array, throw_if_accessed > | VectorView is a template expression that is constructed with a container or scalar, which it then allows to be used as an array using `operator[]`
C stan::VectorView< const Eigen::Matrix< T, R, C >, true, false > |
C stan::VectorView< const std::vector< T >, true, false > |
C stan::VectorView< double, stan::is_vector< T1 >::value, stan::is_constant_struct< T1 >::value > |
C stan::VectorView< double, stan::is_vector< T2 >::value, stan::is_constant_struct< T2 >::value > |
C stan::VectorView< double, stan::is_vector< T3 >::value, stan::is_constant_struct< T3 >::value > |
C stan::VectorView< double, stan::is_vector< T4 >::value, stan::is_constant_struct< T4 >::value > |
C stan::VectorView< double, stan::is_vector< T5 >::value, stan::is_constant_struct< T5 >::value > |
C stan::VectorView< double, stan::is_vector< T6 >::value, stan::is_constant_struct< T6 >::value > |
C stan::VectorView< Eigen::Matrix< T, R, C >, true, false > |
C stan::VectorView< std::vector< T >, true, false > |
C stan::VectorView< T, false, false > |
C stan::VectorView< T, is_array, true > |
C stan::VectorView< T, true, false > |
C stan::VectorView< T_partials_return, stan::is_vector< T1 >::value, stan::is_constant_struct< T1 >::value > |
C stan::VectorView< T_partials_return, stan::is_vector< T2 >::value, stan::is_constant_struct< T2 >::value > |
C stan::VectorView< T_partials_return, stan::is_vector< T3 >::value, stan::is_constant_struct< T3 >::value > |
C stan::VectorView< T_partials_return, stan::is_vector< T4 >::value, stan::is_constant_struct< T4 >::value > |
C stan::VectorView< T_partials_return, stan::is_vector< T5 >::value, stan::is_constant_struct< T5 >::value > |
C stan::VectorView< T_partials_return, stan::is_vector< T6 >::value, stan::is_constant_struct< T6 >::value > |
C stan::VectorView< T_return_type, false, true > |
C stan::VectorViewMvt< T, is_array, throw_if_accessed > |
C stan::VectorViewMvt< const T, is_array, throw_if_accessed > | VectorViewMvt that has const correctness
C stan::math::welford_covar_estimator |
C stan::math::welford_var_estimator |

[ Stan Home Page ] © 2011–2016, Stan Development Team.